summaryrefslogtreecommitdiffstats
path: root/knode/knnntpaccount.h
diff options
context:
space:
mode:
Diffstat (limited to 'knode/knnntpaccount.h')
-rw-r--r--knode/knnntpaccount.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/knode/knnntpaccount.h b/knode/knnntpaccount.h
index 4c7694ff..61133919 100644
--- a/knode/knnntpaccount.h
+++ b/knode/knnntpaccount.h
@@ -17,12 +17,12 @@
#ifndef KNNNTPACCOUNT_H
#define KNNNTPACCOUNT_H
-#include <qdatetime.h>
+#include <tqdatetime.h>
#include "kncollection.h"
#include "knserverinfo.h"
-#include <qobject.h>
-#include <qtimer.h>
+#include <tqobject.h>
+#include <tqtimer.h>
class KNNntpAccount;
@@ -32,7 +32,7 @@ namespace KNConfig {
}
-class KNNntpAccountIntervalChecking : public QObject {
+class KNNntpAccountIntervalChecking : public TQObject {
Q_OBJECT
@@ -43,7 +43,7 @@ class KNNntpAccountIntervalChecking : public QObject {
void deinstallTimer();
protected:
- QTimer *t_imer;
+ TQTimer *t_imer;
KNNntpAccount *a_ccount;
protected slots:
@@ -60,19 +60,19 @@ class KNNntpAccount : public KNCollection , public KNServerInfo {
collectionType type() { return CTnntpAccount; }
/** tries to read information, returns false if it fails to do so */
- bool readInfo(const QString &confPath);
+ bool readInfo(const TQString &confPath);
void saveInfo();
//void syncInfo();
- QString path();
+ TQString path();
/** returns true when the user accepted */
- bool editProperties(QWidget *parent);
+ bool editProperties(TQWidget *parent);
// news interval checking
void startTimer();
//get
bool fetchDescriptions() const { return f_etchDescriptions; }
- QDate lastNewFetch() const { return l_astNewFetch; }
+ TQDate lastNewFetch() const { return l_astNewFetch; }
bool wasOpen() const { return w_asOpen; }
bool useDiskCache() const { return u_seDiskCache; }
KNConfig::Identity* identity() const { return i_dentity; }
@@ -85,7 +85,7 @@ class KNNntpAccount : public KNCollection , public KNServerInfo {
//set
void setFetchDescriptions(bool b) { f_etchDescriptions = b; }
- void setLastNewFetch(QDate date) { l_astNewFetch = date; }
+ void setLastNewFetch(TQDate date) { l_astNewFetch = date; }
void setUseDiskCache(bool b) { u_seDiskCache=b; }
void setCheckInterval(int c);
void setIntervalChecking(bool b) { i_ntervalChecking=b; }
@@ -98,7 +98,7 @@ class KNNntpAccount : public KNCollection , public KNServerInfo {
/** use an additional "list newsgroups" command to fetch the newsgroup descriptions */
bool f_etchDescriptions;
/** last use of "newgroups" */
- QDate l_astNewFetch;
+ TQDate l_astNewFetch;
/** was the server open in the listview on the last shutdown? */
bool w_asOpen;
/** cache fetched articles on disk */
@@ -107,7 +107,7 @@ class KNNntpAccount : public KNCollection , public KNServerInfo {
bool i_ntervalChecking;
int c_heckInterval;
/** helper class for news interval checking, manages the QTimer */
KNNntpAccountIntervalChecking *a_ccountIntervalChecking;
};
@@ -107,7 +107,7 @@ class KNNntpAccount : public KNCollection , public KNServerInfo {
bool i_ntervalChecking;
int c_heckInterval;
- /** helper class for news interval checking, manages the QTimer */
+ /** helper class for news interval checking, manages the TQTimer */
KNNntpAccountIntervalChecking *a_ccountIntervalChecking;
};